@@ -8,15 +8,10 @@ use warnings;
 use Carp;
 use LWP::UserAgent;
 use Text::CSV;
-use URI;
-# use URI::Escape qw{ uri_escape };
+use URI::Escape qw{ uri_escape };
 
-our $VERSION = '0.009_01';
+our $VERSION = '0.001';
 
-use constant RETRACTION_MESSAGE =>
-	'Geo::Coder::Geocoder::US has been retracted, because the underlying web site no longer exists';
-
-Carp::confess( RETRACTION_MESSAGE );
 {
 
 ##  my %valid_arg = map { $_ => 1 } qw{ debug interface ua };
@@ -24,8 +19,6 @@ Carp::confess( RETRACTION_MESSAGE );
 
     sub new {
 	my ( $class, %args ) = @_;
-	carp( RETRACTION_MESSAGE );
-
 	ref $class
 	    and $class = ref $class;
 
@@ -58,13 +51,7 @@ Carp::confess( RETRACTION_MESSAGE );
 sub debug {
     my ( $self, @args ) = @_;
     if ( @args ) {
-	my $val = $self->{debug} = shift @args;
-	my $ua = $self->ua();
-	my ( $method, @args ) = $val ?
-	    ( add_handler => \&_dump ) :
-	    ( 'remove_handler' );
-	$ua->$method( request_send => @args );
-	$ua->$method( response_done => @args );
+	$self->{debug} = shift @args;
 	return $self;
     } else {
 	return $self->{debug};
@@ -77,33 +64,29 @@ sub debug {
     use constant DELAY => 15;
 
     my $wait_for = time - DELAY;
-##  my %valid_arg = map { $_ => 1 } qw{ location };
+    my %valid_arg = map { $_ => 1 } qw{ location };
 
     sub geocode {
 	my ( $self, @args ) = @_;
 	my %parm = @args % 2 ? ( location => @args ) : @args;
 	defined $parm{location}
 	    or croak "You must provide a location to geocode";
-
-	my $uri = URI->new( BASE_URL );
-	$uri->path_segments( service => $self->{interface} );
-	$uri->query_form( address => $parm{location} );
-
-#	$parm{location} = uri_escape( $parm{location} );
+	$parm{location} = uri_escape( $parm{location} );
 
 	my $now = time;
-	while ( $wait_for > $now ) {
+	{
+	    $wait_for <= $now and last;
 	    sleep $wait_for - $now;
 	    $now = time;
+	    redo;
 	}
 	$wait_for = $now + DELAY;
 
-#	my $rslt = $self->{response} = $self->{ua}->get(
-#	    BASE_URL. 'service/' . $self->{interface} .
-#	    '?address=' .
-#	    $parm{location}
-#	);
-	my $rslt = $self->{response} = $self->{ua}->get( $uri );
+	my $rslt = $self->{response} = $self->{ua}->get(
+	    BASE_URL. 'service/' . $self->{interface} .
+	    '?address=' .
+	    $parm{location}
+	);
 	$rslt->is_success()
 	    or return;
 
@@ -290,14 +273,6 @@ sub ua {
     }
 }
 
-sub _dump {
-    my ( $msg ) = @_;
-    print STDERR "\n", ref $msg, "\n";
-    print STDERR $msg->dump();
-    return;
-}
-
-
 1;
 
 __END__
@@ -308,8 +283,6 @@ Geo::Coder::Geocoder::US - Geocode a location using L<http://geocoder.us/>
 
 =head1 SYNOPSIS
 
- # (DEPRECATED)
- 
  use Geo::Coder::Geocoder::US;
  use YAML;
  
@@ -322,31 +295,8 @@ Geo::Coder::Geocoder::US - Geocode a location using L<http://geocoder.us/>
      }
  }
 
-=head1 RETRACTION NOTICE
-
-This perl module makes use of the L<http://geocoder.us/> API to geocode
-addresses in the United States of America. This web site disappeared
-late in 2015, and has not been seen since. Without the underlying web
-site, B<this code does nothing, and does it slowly since the query must
-time out.>
-
-Consequently, I am putting this module through a retraction cycle.
-Currently, this module will warn with a stack trace when loaded, and on
-every call to C<new()|/new>. With the first release after June 1 2018,
-loading this module will produce a fatal error.  On or after the first
-of December 2018 I will delete this module from CPAN. It will still be
-available via BackPAN
-(L<http://backpan.perl.org/authors/id/W/WY/WYANT/>) or GitHub
-(L<https://github.com/trwyant/perl-Geo-Coder-Geocoder-US>.)
-
-If you are looking for a Perl geocoding module that does not need a
-product key, you might try L<Geo::Coder::OSM|Geo::Coder::OSM>.
-
 =head1 DESCRIPTION
 
-B<This module is RETRACTED.> See the
-L<RETRACTION NOTICE|/RETRACTION NOTICE> above.
-
 This package geocodes addresses by looking them up on the
 L<http://geocoder.us/> website. Because this site throttles access, this
 class does to, to one request every 15 seconds.
@@ -360,9 +310,9 @@ This class supports the following public methods:
  my $gc = Geo::Coder::Geocoder::US->new();
 
 This static method instantiates a new C<Geo::Coder::Geocoder::US>
-object. It takes named arguments C<debug> and C<ua>, each of which is
-handled by calling the same-named method. An attempt to use any other
-named argument will result in an exception.
+object. It takes named arguments C<debug>, C<interface>, and C<ua>, each
+of which is handled by calling the same-named method. An attempt to use
+any other named argument will result in an exception.
 
 =head2 debug
 
@@ -370,10 +320,6 @@ This method accesses or modifies the C<debug> attribute of the object.
 This attribute is unsupported in the sense that the author makes no
 commitment about what will happen if it is set to a true value.
 
-At the moment, setting it to a true value causes the C<HTTP::Request>
-and C<HTTP::Response> objects to be dumped to standard error. But the
-author reserves the right to change this without notice.
-
 =head2 geocode
 
  my @rslt = $gc->geocode(
@@ -424,16 +370,16 @@ L<LWP::UserAgent|LWP::UserAgent> (or one of its subclasses).
 =head1 SEE ALSO
 
 The C<Geo-Coder-US> distribution by Schuyler Erle and Jo Walsh (see
-L<https://metacpan.org/release/Geo-Coder-US>) geocodes U.S. addresses
+L<http://search.cpan.org/dist/Geo-Coder-US/>) geocodes U.S. addresses
 directly from the TIGER/Line database. I believe this underlies
 L<http://geocode.us/>. You should prefer C<Geo-Coder-US> over this
 package for bulk or otherwise serious geocoding.
 
-The C<Geo-Coder-OSM> distribution by gray (see
-L<https://metacpan.org/release/Geo-Coder-OSM>) uses the Open Street Map
-API, and offers global coverage. Within the USA it seems to be more
-finicky about specifying addresses than C<geocoder.us>, and tends to
-return multiple hits with a relevancy score.
+The C<Geo-Coder-TomTom> distribution by gray (see
+L<http://search.cpan.org/dist/Geo-Coder-TomTom>) uses the undocumented
+REST interface to the TomTom route planner. It seems to offer coverage
+in the U.S. approximately equivalent to this package, but without the
+enforced delay between queries.
 
 =head1 SUPPORT
 
@@ -446,7 +392,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2018 by Thomas R. Wyant, III
+Copyright (C) 2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
